# -*- coding: ISO-8859-1 -*-
# Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>

import re
import string
import _pg

class Db:
    """This is a simple wrapper class to wrap calls
    to database. Using such a wrapper allows us to
    put various callbacks, logs, and ultimately change
    the module used to access the database."""
    def __init__(self,name,host,port,login,password):
        """Constructor connects directly to the
        database."""
        self.cnx=_pg.connect(name,host,int(port),user=login,passwd=password)
    def query(self,str):
        """Sends a request to the PostGreSQL server."""
        return self.cnx.query(str)
    def query_dict(self,str):
        """Sends a request to the PostGreSQL server, and if the request
        returns a result, it sends the result as a list of dictionnaries."""
        res=None
        rs=self.query(str)
        if rs:
            res=rs.dictresult()
        if not res:
            # res to [] so that function always returns a list
            res=[]
        return res
    def escape(self,par):
        """Escapes a string for ' characters."""
        par=string.replace(str(par),"'","''")
        # Clearly a performance killer...
        for c in [ chr(c) for c in range(0,10)+range(11,13)+range(14,32)] + [ "\"", "\\"]:
            par=string.replace(par,c," ")
        return par
    def multilinestring2python(self,str):
        """Transform an SQL/PostGIS representation of a multilinestring
        object into a Python structure (list of tuples). This is a member
        of the Db class for it's convenient to access it this way, however
        it could be a plain function since self isn't necessary."""
        regex=re.compile("MULTILINESTRING\s*\(\s*\(([\d\.\,\s]+)\)\s*\)")
        coord=regex.search(str).groups()[0]
        result=[ tuple(x.split(" ")) for x in coord.split(",")]
        return result
    def point2python(self,str):
        """Transform an SQL/PostGIS representation of a piint
        object into a Python structure (a tuple). This is a member
        of the Db class for it's convenient to access it this way, however
        it could be a plain function since self isn't necessary."""
        regex=re.compile("POINT\s*\(([\d\.\s]+)\)")
        coord=regex.search(str).groups()[0]
        result=[float(i) for i in coord.split(" ")]
        while len(result)<3:
            result.append(0);
        return result
        
        

        


