-- Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>

DROP TABLE pygpsweb_user CASCADE;
CREATE TABLE pygpsweb_user (
	user_id serial PRIMARY KEY,
	user_login varchar(15) UNIQUE NOT NULL,
	user_passwd varchar(63) NOT NULL, 
	user_name varchar(63) NOT NULL,
	user_email varchar(255)
);

DROP TABLE pygpsweb_file CASCADE;
CREATE TABLE pygpsweb_file (
	file_id serial PRIMARY KEY,
	file_name varchar(63) UNIQUE NOT NULL,
	file_user integer NOT NULL CONSTRAINT pygpsweb_file_ref_user REFERENCES pygpsweb_user(user_id) ON DELETE CASCADE,
	file_description TEXT
);

DROP TABLE pygpsweb_route CASCADE;
CREATE TABLE pygpsweb_route ( 
	route_id serial PRIMARY KEY,
	route_gpsid varchar(6) UNIQUE NOT NULL,
	route_file integer NOT NULL CONSTRAINT pygpsweb_route_ref_file REFERENCES pygpsweb_file(file_id) ON DELETE CASCADE,
	route_description TEXT
);

DROP TABLE pygpsweb_waypoint CASCADE;
CREATE TABLE pygpsweb_waypoint ( 
	waypoint_id serial PRIMARY KEY,
	waypoint_gpsid varchar(6) UNIQUE NOT NULL,
	waypoint_file integer NOT NULL CONSTRAINT pygpsweb_waypoint_ref_file REFERENCES pygpsweb_file(file_id) ON DELETE CASCADE,
	waypoint_symbol varchar(15),
	waypoint_description TEXT
-- No geom data here, in fact AddGeometryColumn does the job
);
SELECT AddGeometryColumn('pygpsweb_waypoint', 'waypoint_geom', -1, 'POINT', 3 );
DROP TABLE pygpsweb_routepoint CASCADE;
CREATE TABLE pygpsweb_routepoint ( 
	routepoint_route integer NOT NULL CONSTRAINT pygpsweb_routepoint_ref_route REFERENCES pygpsweb_route(route_id) ON DELETE CASCADE,
	routepoint_waypoint integer NOT NULL CONSTRAINT pygpsweb_routepoint_ref_waypoint REFERENCES pygpsweb_waypoint(waypoint_id) ON DELETE CASCADE,
	routepoint_order integer UNIQUE NOT NULL,
	PRIMARY KEY(routepoint_route, routepoint_waypoint)
);

DROP TABLE pygpsweb_track CASCADE;
CREATE TABLE pygpsweb_track ( 
	track_id serial PRIMARY KEY,
	track_gpsid varchar(6) UNIQUE NOT NULL,
	track_file integer NOT NULL CONSTRAINT pygpsweb_track_ref_file REFERENCES pygpsweb_file(file_id) ON DELETE CASCADE,
	track_description TEXT
);

DROP TABLE pygpsweb_trackpoint CASCADE;
CREATE TABLE pygpsweb_trackpoint ( 
	trackpoint_id serial PRIMARY KEY,
	trackpoint_track integer NOT NULL CONSTRAINT pygpsweb_trackpoint_ref_track REFERENCES pygpsweb_track(track_id) ON DELETE CASCADE,
	trackpoint_time timestamp with time zone NOT NULL
-- No geom data here, in fact AddGeometryColumn does the job
);
SELECT AddGeometryColumn('pygpsweb_trackpoint', 'trackpoint_geom', -1, 'POINT', 3 );

